#!/bin/bash

# Installer script for qq2clone

#------------------------------------------------------------------------#
# Copyright 2021, Jesse Gardner                                          #
#------------------------------------------------------------------------#
# This file is part of qq2clone.                                         #
#                                                                        #
# qq2clone is free software: you can redistribute it and/or modify       #
# it under the terms of the GNU General Public License as published by   #
# the Free Software Foundation, either version 2 of the License, or      #
# (at your option) any later version.                                    #
#                                                                        #
# qq2clone is distributed in the hope that it will be useful,            #
# but WITHOUT ANY WARRANTY; without even the implied warranty of         #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          #
# GNU General Public License for more details.                           #
#                                                                        #
# You should have received a copy of the GNU General Public License      #
# along with qq2clone.  If not, see <https://www.gnu.org/licenses/>.     #
#------------------------------------------------------------------------#

# base64 encoded tgz archive will be added by gen_all.bash in archive below

archive='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'

[[ -z "$HOME" ]] &&
  { echo '$HOME must be defined'; exit 1; }

temp_dir="$(mktemp -d)" ||
  { echo "Failed to create temp directory"; exit 1; }
trap "rm -rf \"${temp_dir:?}\" &>/dev/null" EXIT

{
  cd "$temp_dir" &&
  echo "$archive" | base64 -d > archive.tgz &&
  tar -xzf archive.tgz &&
  rm archive.tgz
} || { echo "Problem unpacking data to $temp_dir"; exit 1; }

declare input="" location="${HOME}/storage-qq2clone"
while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
  echo "[y/n] Use default storage directory '$location' ?"
  read -rn1 input; echo
done

while [[ ! "$input" =~ (y|Y) ]]; do
  echo "Type in new location"
  read -r location; input=""
  while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
    echo "[y/n] Accept location '$location' ?"
    read -rn 1 input; echo
  done
done
echo

{
  mkdir -p "${HOME}/.config" &&
  echo "$location" > "${HOME}/.config/qq2clone"
} || { echo "Failed to write to ${HOME}/.config/qq2clone"; exit 1; }

{
  mkdir -p "$location" &&
  find -mindepth 1 -exec mv \{\} "$location"/\{\} \;
} || { echo "Cannot create/write to '$location'"; exit 1; }

if { command -v sudo &>/dev/null || [[ "$USER" == "root" ]]; }; then

  input=""
  qq_moved=0
  while : ; do
    while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
      echo "[y/n] Move main script file to /usr/bin/qq2clone ?"
      read -rn 1 input; echo
    done
    if [[ "$input" =~ ^(y|Y)$ ]]; then
      success=1
      if [[ "$USER" == "root" ]]; then
        mv "${location}/qq2clone" /usr/bin/qq2clone || success=0
      else
        sudo mv "${location}/qq2clone" /usr/bin/qq2clone || success=0
      fi
      ((success)) && { echo "File moved"; qq_moved=1; break; }
      echo "Attempt failed."; input=""; continue
    else
      echo "You have chosen to leave the main script file at:"
      echo "  ${location}/qq2clone"
      break
    fi
  done
  echo

  input=""
  while : ; do
    while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
      echo "[y/n] Move man page to /usr/local/man/man1/qq2clone.1 ?"
      read -rn 1 input; echo
    done
    if [[ "$input" =~ ^(y|Y)$ ]]; then
      success=1
      if [[ "$USER" == "root" ]]; then
        {
          mkdir -p /usr/local/man/man1 &&
          mv "${location}/qq2clone.1" /usr/local/man/man1/qq2clone.1
        } ||
          success=0
      else
        {
          sudo mkdir -p /usr/local/man/man1 &&
          sudo mv "${location}/qq2clone.1" /usr/local/man/man1/qq2clone.1
        } ||
          success=0
      fi
      ((success)) && { echo "File moved"; break; }
      echo "Attempt failed."; input=""; continue
    else
      echo "You have chosen to leave the man page at:"
      echo "  ${location}/qq2clone.1"
      break
    fi
  done

else
  echo "sudo is not installed on this system, so script and man page files"
  echo "will not be moved to /usr/bin/ and /usr/local/man"
  echo "  [Main script] ${location}/qq2clone"
  echo "  [Man page]    ${location}/qq2clone.1"
  echo "Manually move these files to desired location on this system"
fi
echo

input=""
while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
  echo "[y/n] qq2clone has a bash completion script. Modify ~/.bashrc to"
  echo "      source the completion script?"
  read -rn 1 input; echo
done

if [[ "$input" =~ ^(y|Y)$ ]]; then
  if echo "source ${location}/qq2clone_completion.bash" >> \
       "${HOME}/.bashrc"; then
    echo ".bashrc modified."
  else
    echo "Failed to write to ${HOME}/.bashrc . Completion script is"
    echo "available at:"
    echo "  ${location}/qq2clone_completion.bash"
  fi
else
  echo "Completion script is available at:"
  echo "  ${location}/qq2clone_completion.bash"
fi
echo

if ((qq_moved)); then
  /usr/bin/qq2clone setup
else
  "${location}/qq2clone" setup
fi
setup_code=$?

if ((setup_code != 0)); then
  echo "Setup failed. Resolve problem(s) described, then manually run"
  echo "the setup again using: qq2clone setup"
fi

exit $setup_code
